#!/bin/bash

# Installer script for qq2clone

#------------------------------------------------------------------------#
# Copyright 2021, Jesse Gardner                                          #
#------------------------------------------------------------------------#
# This file is part of qq2clone.                                         #
#                                                                        #
# qq2clone is free software: you can redistribute it and/or modify       #
# it under the terms of the GNU General Public License as published by   #
# the Free Software Foundation, either version 2 of the License, or      #
# (at your option) any later version.                                    #
#                                                                        #
# qq2clone is distributed in the hope that it will be useful,            #
# but WITHOUT ANY WARRANTY; without even the implied warranty of         #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          #
# GNU General Public License for more details.                           #
#                                                                        #
# You should have received a copy of the GNU General Public License      #
# along with qq2clone.  If not, see <https://www.gnu.org/licenses/>.     #
#------------------------------------------------------------------------#

# base64 encoded tgz archive will be added by gen_all.bash in archive below

archive='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'

[[ -z "$HOME" ]] &&
  { echo '$HOME must be defined'; exit 1; }

temp_dir="$(mktemp -d)" ||
  { echo "Failed to create temp directory"; exit 1; }
trap "rm -rf \"${temp_dir:?}\" &>/dev/null" EXIT

{
  cd "$temp_dir" &&
  echo "$archive" | base64 -d > archive.tgz &&
  tar -xzf archive.tgz &&
  rm archive.tgz
} || { echo "Problem unpacking data to $temp_dir"; exit 1; }

declare input="" location="${HOME}/storage-qq2clone"
while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
  echo "[y/n] Use default storage directory '$location' ?"
  read -rn1 input; echo
done

while [[ ! "$input" =~ (y|Y) ]]; do
  echo "Type in new location"
  read -r location; input=""
  while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
    echo "[y/n] Accept location '$location' ?"
    read -rn 1 input; echo
  done
done
echo

{
  mkdir -p "${HOME}/.config" &&
  echo "$location" > "${HOME}/.config/qq2clone"
} || { echo "Failed to write to ${HOME}/.config/qq2clone"; exit 1; }

{
  mkdir -p "$location" &&
  find -mindepth 1 -exec mv \{\} "$location"/\{\} \;
} || { echo "Cannot create/write to '$location'"; exit 1; }

if { command -v sudo &>/dev/null || [[ "$USER" == "root" ]]; }; then

  input=""
  qq_moved=0
  while : ; do
    while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
      echo "[y/n] Move main script file to /usr/bin/qq2clone ?"
      read -rn 1 input; echo
    done
    if [[ "$input" =~ ^(y|Y)$ ]]; then
      success=1
      if [[ "$USER" == "root" ]]; then
        mv "${location}/qq2clone" /usr/bin/qq2clone || success=0
      else
        sudo mv "${location}/qq2clone" /usr/bin/qq2clone || success=0
      fi
      ((success)) && { echo "File moved"; qq_moved=1; break; }
      echo "Attempt failed."; input=""; continue
    else
      echo "You have chosen to leave the main script file at:"
      echo "  ${location}/qq2clone"
      break
    fi
  done
  echo

  input=""
  while : ; do
    while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
      echo "[y/n] Move man page to /usr/local/man/man1/qq2clone.1 ?"
      read -rn 1 input; echo
    done
    if [[ "$input" =~ ^(y|Y)$ ]]; then
      success=1
      if [[ "$USER" == "root" ]]; then
        {
          mkdir -p /usr/local/man/man1 &&
          mv "${location}/qq2clone.1" /usr/local/man/man1/qq2clone.1
        } ||
          success=0
      else
        {
          sudo mkdir -p /usr/local/man/man1 &&
          sudo mv "${location}/qq2clone.1" /usr/local/man/man1/qq2clone.1
        } ||
          success=0
      fi
      ((success)) && { echo "File moved"; break; }
      echo "Attempt failed."; input=""; continue
    else
      echo "You have chosen to leave the man page at:"
      echo "  ${location}/qq2clone.1"
      break
    fi
  done

else
  echo "sudo is not installed on this system, so script and man page files"
  echo "will not be moved to /usr/bin/ and /usr/local/man"
  echo "  [Main script] ${location}/qq2clone"
  echo "  [Man page]    ${location}/qq2clone.1"
  echo "Manually move these files to desired location on this system"
fi
echo

input=""
while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
  echo "[y/n] qq2clone has a bash completion script. Modify ~/.bashrc to"
  echo "      source the completion script?"
  read -rn 1 input; echo
done

if [[ "$input" =~ ^(y|Y)$ ]]; then
  if echo "source ${location}/qq2clone_completion.bash" >> \
       "${HOME}/.bashrc"; then
    echo ".bashrc modified."
  else
    echo "Failed to write to ${HOME}/.bashrc . Completion script is"
    echo "available at:"
    echo "  ${location}/qq2clone_completion.bash"
  fi
else
  echo "Completion script is available at:"
  echo "  ${location}/qq2clone_completion.bash"
fi
echo

if ((qq_moved)); then
  /usr/bin/qq2clone setup
else
  "${location}/qq2clone" setup
fi
setup_code=$?

if ((setup_code != 0)); then
  echo "Setup failed. Resolve problem(s) described, then manually run"
  echo "the setup again using: qq2clone setup"
fi

exit $setup_code
